#!/bin/bash

# Installer script for qq2clone

#------------------------------------------------------------------------#
# Copyright 2021, Jesse Gardner                                          #
#------------------------------------------------------------------------#
# This file is part of qq2clone.                                         #
#                                                                        #
# qq2clone is free software: you can redistribute it and/or modify       #
# it under the terms of the GNU General Public License as published by   #
# the Free Software Foundation, either version 2 of the License, or      #
# (at your option) any later version.                                    #
#                                                                        #
# qq2clone is distributed in the hope that it will be useful,            #
# but WITHOUT ANY WARRANTY; without even the implied warranty of         #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          #
# GNU General Public License for more details.                           #
#                                                                        #
# You should have received a copy of the GNU General Public License      #
# along with qq2clone.  If not, see <https://www.gnu.org/licenses/>.     #
#------------------------------------------------------------------------#

# base64 encoded tgz archive will be added by gen_all.bash in archive below

archive='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'

[[ -z "$HOME" ]] &&
  { echo '$HOME must be defined'; exit 1; }

temp_dir="$(mktemp -d)" ||
  { echo "Failed to create temp directory"; exit 1; }
trap "rm -rf \"${temp_dir:?}\" &>/dev/null" EXIT

{
  cd "$temp_dir" &&
  echo "$archive" | base64 -d > archive.tgz &&
  tar -xzf archive.tgz &&
  rm archive.tgz
} || { echo "Problem unpacking data to $temp_dir"; exit 1; }

declare input="" location="${HOME}/storage-qq2clone"
while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
  echo "[y/n] Use default storage directory '$location' ?"
  read -rn1 input; echo
done

while [[ ! "$input" =~ (y|Y) ]]; do
  echo "Type in new location"
  read -r location; input=""
  while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
    echo "[y/n] Accept location '$location' ?"
    read -rn 1 input; echo
  done
done
echo

{
  mkdir -p "${HOME}/.config" &&
  echo "$location" > "${HOME}/.config/qq2clone"
} || { echo "Failed to write to ${HOME}/.config/qq2clone"; exit 1; }

{
  mkdir -p "$location" &&
  find -mindepth 1 -exec mv \{\} "$location"/\{\} \;
} || { echo "Cannot create/write to '$location'"; exit 1; }

if { command -v sudo &>/dev/null || [[ "$USER" == "root" ]]; }; then

  input=""
  qq_moved=0
  while : ; do
    while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
      echo "[y/n] Move main script file to /usr/bin/qq2clone ?"
      read -rn 1 input; echo
    done
    if [[ "$input" =~ ^(y|Y)$ ]]; then
      success=1
      if [[ "$USER" == "root" ]]; then
        mv "${location}/qq2clone" /usr/bin/qq2clone || success=0
      else
        sudo mv "${location}/qq2clone" /usr/bin/qq2clone || success=0
      fi
      ((success)) && { echo "File moved"; qq_moved=1; break; }
      echo "Attempt failed."; input=""; continue
    else
      echo "You have chosen to leave the main script file at:"
      echo "  ${location}/qq2clone"
      break
    fi
  done
  echo

  input=""
  while : ; do
    while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
      echo "[y/n] Move man page to /usr/local/man/man1/qq2clone.1 ?"
      read -rn 1 input; echo
    done
    if [[ "$input" =~ ^(y|Y)$ ]]; then
      success=1
      if [[ "$USER" == "root" ]]; then
        {
          mkdir -p /usr/local/man/man1 &&
          mv "${location}/qq2clone.1" /usr/local/man/man1/qq2clone.1
        } ||
          success=0
      else
        {
          sudo mkdir -p /usr/local/man/man1 &&
          sudo mv "${location}/qq2clone.1" /usr/local/man/man1/qq2clone.1
        } ||
          success=0
      fi
      ((success)) && { echo "File moved"; break; }
      echo "Attempt failed."; input=""; continue
    else
      echo "You have chosen to leave the man page at:"
      echo "  ${location}/qq2clone.1"
      break
    fi
  done

else
  echo "sudo is not installed on this system, so script and man page files"
  echo "will not be moved to /usr/bin/ and /usr/local/man"
  echo "  [Main script] ${location}/qq2clone"
  echo "  [Man page]    ${location}/qq2clone.1"
  echo "Manually move these files to desired location on this system"
fi
echo

input=""
while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
  echo "[y/n] qq2clone has a bash completion script. Modify ~/.bashrc to"
  echo "      source the completion script?"
  read -rn 1 input; echo
done

if [[ "$input" =~ ^(y|Y)$ ]]; then
  if echo "source ${location}/qq2clone_completion.bash" >> \
       "${HOME}/.bashrc"; then
    echo ".bashrc modified."
  else
    echo "Failed to write to ${HOME}/.bashrc . Completion script is"
    echo "available at:"
    echo "  ${location}/qq2clone_completion.bash"
  fi
else
  echo "Completion script is available at:"
  echo "  ${location}/qq2clone_completion.bash"
fi
echo

if ((qq_moved)); then
  /usr/bin/qq2clone setup
else
  "${location}/qq2clone" setup
fi
setup_code=$?

if ((setup_code != 0)); then
  echo "Setup failed. Resolve problem(s) described, then manually run"
  echo "the setup again using: qq2clone setup"
fi

exit $setup_code
